# Installation
!!! warning "Requirements"
    This project requires :simple-python: >= 3.10.

---

## Creating a virtual environment
It is highly advised to create a new virtual environment before installing this package.
=== ":simple-uv: uv"
    ```console
    $ uv venv
    ```
=== ":simple-python: pip"
    ```console
    $ python -m venv .venv
    ```

!!! note
    When using the default virtual environment name (i.e.: _.venv_), uv will automatically find and use the virtual environment during subsequent invocations.

Then, activate the virtual environment
=== ":material-linux: Linux"
    ```console
    $ source .venv/bin/activate
    ```
=== ":material-microsoft-windows: cmd"
    ```console
    > .\.venv\Scripts\activate.bat
    ```
=== ":material-powershell: PowerShell"
    ```console
    > .\.venv\Scripts\Activate.ps1
    ```

## Installing the package
!!! note
    This will install :simple-pytorch: compiled with CUDA.

=== ":simple-uv: uv"
    ```console
    $ uv pip install git+https://github.com/RistoAle97/centered-kernel-alignment
    ```
=== ":simple-python: pip"
    ```console
    $ pip install git+https://github.com/RistoAle97/centered-kernel-alignment
    ```

## Contributing
If you want to contribute to improve the source:

1. fork the repository on :simple-github:
1. create a new branch where to commit your changes
1. clone it
    ```console
    $ git clone https://github.com/RistoAle97/centered-kernel-alignment
    ```

You will need to install the development dependencies
=== ":simple-uv: uv"
    ```console
    $ uv pip install -e centered-kernel-alignment
    $ uv pip install ckatorch --group dev
    ```
=== ":simple-python: pip"
    ```console
    $ pip install -e centered-kernel-alignment
    $ pip install ckatorch --group dev
    ```
Feel free to open a pull request after you have commited your changes :heart:.